# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid debug* files interfering with manifest test:
%global debug_package %{nil}

# Similarly for .package_note* files
%undefine _package_note_file

#TODO: BR: perl(Perl::Critic::Policy::Variables::ProhibitUnusedVarsStricter) when available
#TODO: BR: perl(Text::CSV) when available

Name:		perl-PPIx-Regexp
Version:	0.088
Release:	1.%{__distinit}%{__distvers}
Summary:	Represent a regular expression of some sort
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/PPIx-Regexp
Source0:	https://cpan.metacpan.org/authors/id/W/WY/WYANT/PPIx-Regexp-%{version}.tar.gz
BuildArch:	noarch
# ----------------------------------------------------------------------------
# Module build requirements
# ----------------------------------------------------------------------------
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(lib)
BuildRequires:	perl(Module::Metadata)
BuildRequires:	sed
# ----------------------------------------------------------------------------
# Module requirements
# ----------------------------------------------------------------------------
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(overload)
BuildRequires:	perl(PPI::Document) >= 1.238
BuildRequires:	perl(PPI::Dumper) >= 1.238
BuildRequires:	perl(Scalar::Util) >= 1.10
BuildRequires:	perl(strict)
BuildRequires:	perl(Task::Weaken)
BuildRequires:	perl(warnings)
# ----------------------------------------------------------------------------
# Regular test suite requirements
# ----------------------------------------------------------------------------
BuildRequires:	perl(charnames)
BuildRequires:	perl(open)
BuildRequires:	perl(Test::More) >= 0.88
# ----------------------------------------------------------------------------
# Optional test suite requirements
# ----------------------------------------------------------------------------
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(YAML)
# ----------------------------------------------------------------------------
# Release test requirements (spelling check intentionally skipped)
# ----------------------------------------------------------------------------
%if 0%{?fedora} > 30 || 0%{?rhel} > 8
BuildRequires:	perl-doc
%endif
BuildRequires:	perl(ExtUtils::Manifest)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::CPAN::Changes)
# perl-Test-Kwalitee → perl-Test-CleanNamespaces → perl-Moose → perl-DBM-Deep
#		→ perl-DBD-SQLite → perl-Perl-MinimumVersion → perl-PPIx-Regexp
# Test::Perl::Critic → Perl::Critic → PPIx::Regexp
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Perl::MinimumVersion) >= 1.38
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::Perl::Critic)
%endif
BuildRequires:	perl(Pod::Perldoc)
BuildRequires:	perl(Test::Pod) >= 1.0
BuildRequires:	perl(Test::Pod::Coverage) >= 1.0
BuildRequires:	perl(version)
# ----------------------------------------------------------------------------
# Runtime requirements not automatically picked up by RPM
# ----------------------------------------------------------------------------
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Encode)
Requires:	perl(PPI::Document) >= 1.238
Requires:	perl(PPI::Dumper) >= 1.238
Requires:	perl(Task::Weaken)

%description
The purpose of the PPIx-Regexp package is to parse regular expressions in a
manner similar to the way the PPI package parses Perl. This class forms the
root of the parse tree, playing a role similar to PPI::Document.

%prep
%setup -q -n PPIx-Regexp-%{version}

# Make sure we don't get bogus docfile dependencies
chmod -c -x eg/*
sed -i '1 s|/usr/local/bin/perl|/usr/bin/perl|' eg/*
sed -i '1 s|/usr/bin/env perl|/usr/bin/perl|' eg/*

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
# author test requires "perldoc perluniprops" to work
# The file needed is in the perl-doc package from Fedora 31 onwards
make authortest

%files
%license LICENSES/*
%doc Changes CONTRIBUTING eg/ README
%{perl_vendorlib}/PPIx/
%{_mandir}/man3/PPIx::Regexp*.3*

%changelog
* Tue Feb 28 2023 Paul Howarth <paul@city-fan.org> - 0.088-1
- Update to 0.088
  - Remove support for (**{ ... code ... })
    This was introduced in Perl 5.37.8 along with a single-splat version
    The double-splat version was removed without deprecation in Perl 5.37.9, so
    it is being removed without deprecation here as well, per my stated policy
    about development functionality
    The single-splat version still exists (and is documented) in Perl 5.37.9,
    and in this package

* Sun Jan 29 2023 Paul Howarth <paul@city-fan.org> - 0.087-1
- Update to 0.087
  - Add support for code in optimized regex, a.k.a. (*{...}); this involved
    making the recognition of backtracking control more specific, since it also
    uses (?*...)
  - If (*{...}) and (**{...}) are removed from Perl before Perl 5.38.0, support
    for them will be removed from this package

* Wed Dec 14 2022 Paul Howarth <paul@city-fan.org> - 0.086-1
- Update to 0.086
  - Add width(), which returns the number of characters matched
    Note that an indefinite upper bound is represented as IEEE 754 Inf if that
    appears to be supported; otherwise by a singleton object overloaded to
    allow stringification, numification, and numeric tests
  - Use width() to enhance the detection of variable-width look-behinds
  - Serious clean-up on accepts_perl() subsystem
- Use SPDX-format license tag

* Mon Apr 18 2022 Paul Howarth <paul@city-fan.org> - 0.085-1
- Update to 0.085
  - Remove 'postderef' argument to PPIx::Regexp->new(); postfix dereference is
    always recognized

* Sun Apr  3 2022 Paul Howarth <paul@city-fan.org> - 0.084-1
- Update to 0.084
  - Require PPI 1.238 for postfix deref support, and recode the postfix deref
    logic in terms of 1.238's functionality
  - Parse '@{[ ... ]}' as code, not interpolation; this is more in line with
    what it actually represents, and allows correct versioning of postfix
    dereferences (but it is an incompatible change)

* Fri Mar 18 2022 Paul Howarth <paul@city-fan.org> - 0.083-1
- Update to 0.083
  - Correct and optimize the computation of logical column position (the one
    that takes account of tabs)
- Work around package note files breaking xt/author/manifest.t

* Mon Nov 29 2021 Paul Howarth <paul@city-fan.org> - 0.082-1
- Update to 0.082
  - Add --version to eg/predump, and document all options with double dashes
  - Silence 'uninitialized' warning generated by /(?<=.{35})/
  - Try to quell weird Win32 test failures that seem to occur only in tests
    where I am using 'use open' to put the standard handles into UTF-8 mode;
    the fix (I hope) is to do this to the Test::Harness handles at run time
    instead of to the standard handles at compile time
  - Add file CONTRIBUTING

* Fri Oct 22 2021 Paul Howarth <paul@city-fan.org> - 0.081-1
- Update to 0.081
  - Any use of the postderef argument is now fatal
  - Correct generation of 'provides' metadata
  - Add YAPE::Regex to SEE ALSO
- Fix dist tags for Alma and Rocky Linux

* Fri Apr 16 2021 Paul Howarth <paul@city-fan.org> - 0.080-1
- Update to 0.080
  - All uses of the postderef argument to new() now warn

* Fri Mar 26 2021 Paul Howarth <paul@city-fan.org> - 0.079-1
- Update to 0.079
  - Get prerequisites up to snuff, and add xt/author/prereq.t to ensure they
    stay that way
  - Add rt.cpan.org back to bug reporting methods; long live RT!

* Fri Jan 29 2021 Paul Howarth <paul@city-fan.org> - 0.078-1
- Update to 0.078
  - Allow CPAN to index Script_Run, Atomic_Script_Run, since they made it into
    a production release
  - Allow {,3} and { 0 , 3 } as quantifiers, requiring at least Perl 5.33.6;
    previously these parsed as literals (this parse will be retracted if it
    does not make it into 5.34.0)

* Thu Jan 14 2021 Paul Howarth <paul@city-fan.org> - 0.077-1
- Update to 0.077
  - Add Travis CI testing
  - Use GitHub as bug tracker: R.I.P. rt.cpan.org
- Use %%license unconditionally
- Assume we always have Perl ≥ 5.12 now
- Assume we always have rpm ≥ 4.9 now

* Mon Nov 30 2020 Paul Howarth <paul@city-fan.org> - 0.076-1
- Update to 0.076
  - Attempt to correct detection of \K in nested assertions
  - Variable-length look-behind is version 5.029009
  - Look-behinds quantified longer than 255 characters are an error, and are
    made into unknown tokens or structures

* Thu Oct  8 2020 Paul Howarth <paul@city-fan.org> - 0.075-1
- Update to 0.075
  - Warn on first use of attribute 'postderef'

* Tue Sep  8 2020 Paul Howarth <paul@city-fan.org> - 0.074-1
- Update to 0.074
  - Remove PPIx::Regexp::StringTokenizer itself and all documentation referring
    to it or the 'parse' argument to PPIx::Regexp->new()

* Thu Jul 30 2020 Paul Howarth <paul@city-fan.org> - 0.073-1
- Update to 0.073
  - Remove prototypes from testing subroutines defined in t/*.t

* Thu May 21 2020 Paul Howarth <paul@city-fan.org> - 0.072-1
- Update to 0.072
  - Drop dependency on List::MoreUtils

* Sun Mar 29 2020 Paul Howarth <paul@city-fan.org> - 0.071-1
- Update to 0.071
  - Recognize wildcard Unicode names (Perl 5.31.10)
  - Try to get correct line number in derived PPI; this is done by injecting
    "\n" as needed - the initial #line directive becomes "#line 2", but is
    suppressed if I need to generate line 1
  - Improve normalization of content for ppi(); this involves the un-bracketing
    of things like ${foo}
  - Deprecate new() argument postderef
    - At this stage it is only documented as deprecated
    - In the first release after October 1 2020 it will warn on the first use
    - Eventually it will be retracted, and postfix dereferences will always be
      recognized (this is the default behaviour now)
  - Add dump argument/option 'short' which, if true, causes leading
    'PPIx::Regexp::' to be removed from class names

* Fri Feb 28 2020 Paul Howarth <paul@city-fan.org> - 0.070-1
- Update to 0.070
  - Add index_locations option to PPIx::Regexp->new(), which defaults to true
    if the regexp is specified as a PPI::Element object; the locations are
    consistent with the containing PPI::Document
  - Add methods location(), column_number(), line_number(), logical_filename(),
    logical_line_number(), and visual_column_number() to PPIx::Regexp::Element;
    all return undef if the locations could not be determined
  - Add method statement() to PPIx::Regexp::Element, which returns the PPI
    statement containing the regexp element, or nothing if none
  - Add method is_matcher() to PPIx::Regexp::Element, which classifies objects
    as to whether they actually match something in the target string; possible
    returns are true (they do), false but defined (they do not) and undef (no
    clue)
  - Add methods first_token() and last_token() to PPIx::Regexp::Node
  - Add methods next_token() and previous_token() to PPIx::Regexp::Element

* Sat Feb  8 2020 Paul Howarth <paul@city-fan.org> - 0.069-1
- Update to 0.069
  - The PPIx::Regexp->new() 'parse' option is now fatal; this selected either
    string or regex parse (I consider the string parse a failed experiment and
    this is the latest step in removing it in favour of the PPIx::QuoteLike
    package)

* Tue Jan 21 2020 Paul Howarth <paul@city-fan.org> - 0.068-1
- Update to 0.068
  - Expose PPIx::Regexp::Util::is_ppi_regexp_element()
  - explain() on [[=x=]] now calls it a Character Equivalence; it's still a
    PPIx::Regexp::Token::CharClass::POSIX::Unknown (and therefore an error),
    though

* Sat Aug 31 2019 Paul Howarth <paul@city-fan.org> - 0.067-1
- Update to 0.067
  - \K was retracted in Perl 5.31.3, but only inside look-around assertions

* Fri Aug 16 2019 Paul Howarth <paul@city-fan.org> - 0.066-1
- Update to 0.066
  - Fix broken POD, and add test to ensure it remains fixed

* Sat May 25 2019 Paul Howarth <paul@city-fan.org> - 0.065-1
- Update to 0.065
  - Quash undef error in __is_ppi_regexp_element() when passed a
    PPI::Token::Regexp::Transliterate
  - Support proper version for qr'\N{name}'
    - Until 5.29.10 this construction failed to parse because it did not
      interpolate, but PPIx::Regexp blithely ignored this detail
    - As of 5.29.10, something like m'\N{LATIN CAPITAL LETTER L}' matches
      identically to m'L', so I implemented introduction as of that version
    - Have explain() recognize Unicode property wildcards

* Mon Apr  1 2019 Paul Howarth <paul@city-fan.org> - 0.064-1
- Update to 0.064
  - Empty \p{} should be an error
  - \x{} and \x{ non-hex } should be errors under "use re 'strict'"
  - \o{} should be an error
  - \o{ non-octal } should be an error under "use re 'strict'"
  - Support wildcard Unicode property values; these were added in 5.29.9
  - Add eg/find-variable-length-lookarounds
  - Add convenience method extract_regexps(); this is a static method on
    PPIx::Regexp that takes as its argument a PPI::Document and manufactures
    PPIx::Regexp objects out of anything that parses to a regexp of some sort
  - Don't run illegal character tests before Perl 5.18 unless we're author
    testing, because they are noisy; the issue is not the Perl version per se,
    but the version of Unicode: Perl5180delta says it shipped with Unicode 6.2

* Thu Nov  8 2018 Paul Howarth <paul@city-fan.org> - 0.063-1
- Update to 0.063
  - Silence weird-character parse tests and make them no longer author-only
  - Further deprecate 'parse' argument to new(); you now get a warning on each
    use

* Mon Aug 20 2018 Paul Howarth <paul@city-fan.org> - 0.062-1
- Update to 0.062
  - Remove tokenizer method prior(); this is the last step in its deprecation

* Tue Jul 10 2018 Paul Howarth <paul@city-fan.org> - 0.061-1
- Update to 0.061
  - Only standalone graphemes and non-characters allowed as delimiters starting
    with Perl 5.29.0
  - Non-ASCII delimiters started working in 5.8.3, so that is what
    perl_version_introduced() returns for them
  - Collateral with all this, accept word characters as delimiters, but only
    with at least one space between the operator and the expression, i.e.
    'qr xyx' is OK, but 'qrxyx' is not

* Sun Jun 17 2018 Paul Howarth <paul@city-fan.org> - 0.060-1
- Update to 0.060
  - \N{} now parses as the unknown token, not NoOp, regardless of the setting
    of 'use re qw< strict >;' \N{} became unconditionally fatal in 5.28.0
    (5.27.1, actually) (the policy when the parse changes is to use the most
    modern parse, hence this change)
  - As a side effect of this, the unknown token's explain() method now returns
    something - normally the associated error
  - Add method remove_insignificant(); if the invocant isa Node, this returns a
    clone of the invocant with non-significant elements removed and otherwise
    it returns either the invocant or nothing
- Switch upstream from search.cpan.org to metacpan.org

* Wed May  9 2018 Paul Howarth <paul@city-fan.org> - 0.059-1
- Update to 0.059
  - Install @CARP_NOT everywhere so that warnings and exceptions generated in
    the bowels of the system appear to come from the point where the system is
    entered
  - Further deprecate string (versus regexp) parsing: the first use of the
    'parse' argument to new() will result in a warning; if the value of the
    argument is 'guess' or 'string', the warning refers to PPIx::QuoteLike

* Thu Apr 26 2018 Paul Howarth <paul@city-fan.org> - 0.058-1
- Update to 0.058
  - Prefer /[0-9]/ over /\d/ for numeric checks; the latter can match non-ASCII
    digits
  - Explain the negated POSIX character classes, and tweak some of the asserted
    explanations - mostly for readability and parallel construction with the
    negated explanations, but it turns out [[:digit:]] is NOT equivalent to
    [0-9]

* Wed Apr 18 2018 Paul Howarth <paul@city-fan.org> - 0.057-1
- Update to 0.057
  - Allow ->asserts( 'a*' ); this modification actually allows wildcards in
    asserts() on all match semantic modifiers, but it is probably only useful
    in the case of 'a*', because that is the only one that can be doubled
  - Explain grouping structure as 'Grouping', not 'Capture or grouping'
  - Caret modifier was not turning off /n, which was complicated by the fact
    that (?^) was introduced in 5.13.6, but (?n) was not introduced until
    5.21.8; the solution was to include -n in the expansion of the caret if
    and only if /n had been seen in the scope of the caret
  - Recognize caret in /(?^)x/
  - Acknowledge Regexp::Parsertron in SEE ALSO

* Thu Mar  8 2018 Paul Howarth <paul@city-fan.org> - 0.056-1
- Update to 0.056
  - Support removal of unescaped literal left curlys after left parens, which
    was deprecated in 5.27.8; no actual change in output yet, since deprecation
    is not tracked, but the perl_version_removed() logic is there
  - Add next_element() and kin; these are analogous to next_sibling() and kin,
    but will cross over from content proper into structure (beginning and end
    delimiters, etc.) and vice versa
  - Correct requirements_for_perl() for impossible regular expression; it now
    returns '! $]' when the components of the regexp are valid, but none are
    valid under any specific version of Perl - it used to think all Perls were
    OK when this happened
  - Add the alpha_assertions introduced in 5.27.9
  - Handle 5.27.9's change from +script_run to *script_run, and support *sr as
    a synonym

* Fri Feb  9 2018 Paul Howarth <paul@city-fan.org> - 0.055-1
- Update to 0.055
  - Tokenizer method prior() is now fatal; this was documented as
    package-private, but as it WAS documented, I am putting it through a
    deprecation cycle anyway - six months from now it will be removed
  - Add Script_Run classes as subclasses to their superclass docs; this was
    missed in the last update

* Tue Jan 30 2018 Paul Howarth <paul@city-fan.org> - 0.054-2
- Filter dependencies on private packages PPIx::Regexp::Structure::Script_Run
  and PPIx::Regexp::Token::GroupType::Script_Run

* Mon Jan 29 2018 Paul Howarth <paul@city-fan.org> - 0.054-1
- Update to 0.054
  - Add support for (+script_run:...), which is an experimental feature added
    in Perl 5.27.8 and imposes on any matches it contains the additional
    restriction that everything matched has to belong to the same Unicode
    script; this support will be retracted if the functionality does not make
    it into Perl 5.28
  - Add method scontent(), which returns significant content only, i.e., if
    called on the parse of '/ f u b a r /x', it returns '/fubar/x'

* Tue Oct 31 2017 Paul Howarth <paul@city-fan.org> - 0.053-1
- Update to 0.053
  - Recognize \px as Unicode char class; at least, when the x is
    C, L, M, N, P, S or Z
  - The 'parse' argument to new() is now deprecated

* Fri Sep  8 2017 Paul Howarth <paul@city-fan.org> - 0.052-1
- Update to 0.052
  - Clarify Node->find_parents() documentation (CPAN RT#122715)
. - Further deprecate tokenizer method prior() in favour of
    prior_significant_token()
  - Add requirements_for_perl()
    - This is analogous to the CPAN::Meta::Requirements method
      requirements_for_module(), though the output is formatted differently
    - Also put in the actual requirements for an un-escaped literal left curly
      after a constant, which was removed in 5.25.1 and reinstated in 5.27.1
  - Add accepts_perl()
    - This is analogous to CPAN::Meta::Requirements->accepts_module()
    - I decided that CPAN::Meta::Requirements was overkill, but this may turn
      out to be the wrong decision, so I will be careful what I expose
  - Document behaviour of perl_version_introduced() and perl_version_removed()
    when a feature is re-introduced after removal, or re-removed after
    re-introduction
  - \N{} (empty curlys) removed in 5.27.1
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88
  - Only exclude BR: Perl::MinimumVersion when bootstrapping
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jan 29 2017 Paul Howarth <paul@city-fan.org> - 0.051-1
- Update to 0.051
  - Support whitespace inside [] if /xx in effect; starting with Perl 5.25.9, a
    space or tab appearing inside a bracketed character class is not
    significant if /xx is asserted
  - Further deprecate tokenizer method prior()
  - Add 'provides' data to ExtUtils::MakeMaker output
  - SOME unescaped literal '{' removed in 5.025001; after '.', Unicode classes,
    and bracketed classes (including extended), they are still legal
  - Make /\b{/ an error; Perl fails to parse the above, because once it sees
    the '\b{' it wants to find one of the extended boundary assertions (like
    \b{wb}), and declares an error when it does not
- Update patch for building with Test::More < 0.88

* Fri Sep 23 2016 Paul Howarth <paul@city-fan.org> - 0.050-2
- BR: perl-generators where available

* Sat May  7 2016 Paul Howarth <paul@city-fan.org> - 0.050-1
- Update to 0.050
  - Parse bracketed substitution with embedded comment; this is something like
    s{foo}\n#{bar}\n{baz}, which is equivalent to s/foo/baz/
  - We now recognize postfix dereferences by default, since Perl does beginning
    with 5.24; in other words, default new() argument 'postderef' to true
  - Unterminated substitutions (i.e. 's//') should no longer cause an
    exception; instead, they parse as an unknown token
- Update patch for building with Test::More < 0.88

* Wed Apr 20 2016 Paul Howarth <paul@city-fan.org> - 0.049-1
- Update to 0.049
  - Robustify PPIx::Regexp->perl_version_removed(); the problem here was that
    if the expression being parsed was sufficiently badly-formed,
    $self->delimiters() would be undef, throwing a warning
  - Correct dump of embedded modifiers (eg: (?i:...))
- Simplify find command using -delete
- Update patch for building with Test::More < 0.88

* Tue Mar  1 2016 Paul Howarth <paul@city-fan.org> - 0.048-1
- Update to 0.048
  - Add option 'strict', like 'use re "strict"'
    In the presence of strict(), I opted to set perl_version_introduced to the
    version of Perl where the construct became an error
  - Parse '\N{}' as no-op
    The previous parse was a character class ('\N') followed by two literals
    ('{' and '}'), but perl5238delta said that it had been ignored up to that
    time; starting with 5.23.8 it is an error if 'use re strict' is in effect
  - Quash 'NOT a POSIX class ...' warning under 5.23.8
- Update patch for building with Test::More < 0.88

* Sat Jan 30 2016 Paul Howarth <paul@city-fan.org> - 0.047-1
- Update to 0.047
  - Recognize \b{lb}, introduced in 5.23.7; if this is retracted before 5.24,
    it will be removed outright
- Update patch for building with Test::More < 0.88

* Mon Jan 11 2016 Paul Howarth <paul@city-fan.org> - 0.046-1
- Update to 0.046
  - Add GitHub repository to metadata
- Update patch for building with Test::More < 0.88

* Fri Jan  1 2016 Paul Howarth <paul@city-fan.org> - 0.045-1
- Update to 0.045
  - Deprecate tokenizer method prior() in favour of prior_significant_token();
    this is not part of the public interface, so I suppose I could have just
    slam-dunked it, but ...
  - Add experimental ability to parse strings as well as regexes; the new
    functionality is controlled by the new new() argument 'parse', whose
    permitted values are 'regex' (the default), 'string', or 'guess'
- Update patch for building with Test::More < 0.88

* Wed Dec  9 2015 Paul Howarth <paul@city-fan.org> - 0.044-1
- Update to 0.044
  - Recognize postfix dereference if desired, controlled by the Boolean
    argument 'postderef' passed to PPIx::Regexp->new(); the default is false,
    but will become true if postfix dereference becomes mainstream Perl 5
  - Add explain() and supporting methods main_structure() and in_regex_set();
    the explain() method returns a brief explanation of what the element does
  - Restrict recognition of back references in replacement strings to \number
    form, since Perl itself does not recognize \g{...} or \k{...} there
  - Allow nesting of \Q with \U, \L, and \F (the perlop docs say these nest
    with each other); playing with Perl suggests that \U, \L and \F supersede
    each other, but that they as a group nest with \Q in either order, so that
    if you specify \Q and one of the \U, \L, \F group, you need two \Es to turn
    them all back off
- Update patch for building with Test::More < 0.88

* Thu Nov 19 2015 Paul Howarth <paul@city-fan.org> - 0.043-1
- Update to 0.043
  - Beginning with version 0.035, PPIx::Regexp was incorrectly reporting the
    sense of modifiers when the same token both asserted and negated modifiers
    (e.g. '(?x-i:...)'); this release should correct the problem
  - Document policy when Perl changes in such a way that the proper parse for a
    regular expression changes; in this case the more modern parse is preferred
  - Parse white space inside bracketed character classes inside extended
    bracketed character classes (whew!) as literals, except for the space
    character itself and the horizontal tab; this tracks the corresponding
    change in Perl 5.23.4, and will be reverted if the corresponding Perl
    change does not make it into 5.24.0
  - Clear error when lexer identifies unknown token; those who peruse the
    changes in this release will see that a bunch of refactoring was done as
    part of this
  - Parse \U and friends as meta-characters inside \Q...\E; this turns out to
    be what Perl itself does, as shown by "perl -E 'say qr{\Q\Ufoo}'"
  - Do not end regex set prematurely on finding '])'; the problem is that '])'
    can occur within an extended bracketed character class if it contains
    grouping parentheses and the last item in a group is a regular bracketed
    character class and there is no white space between the end of the
    character class and the end of the group
  - Record parse failure if switch condition is unknown; the structure was
    being reblessed to PPIx::Regexp::Structure::Unknown, but the number of
    parse failures was not being incremented
- Update patch for building with Test::More < 0.88

* Sat Oct 10 2015 Paul Howarth <paul@city-fan.org> - 0.042-1
- Update to 0.042
  - Produce parse error in the presence of trailing cruft (CPAN RT#107331)
  - Tweak documentation in PPIx::Regexp
  - Group types were not being recognized if they contained the delimiter
    character for the regexp (e.g. in qr<(?\<foo)> the look-behind assertion
    was not recognized as such)
  - Correct mis-parse of ' s///'; leading white space is supposed to be
    acceptable, but the leading whitespace token caused
    PPIx::Regexp::Lexer not to recognize the substitution as such
  - Tokenizer was failing when the string to be parsed was so bad it was
    trying to return the whole thing as a single PPIx::Regexp::Token::Unknown
  - PPIx::Regexp::Dumper now displays a message if a structure is missing its
    end delimiter
  - Report error rather than failing when parsing a string consisting wholly
    of white space
- Update patch for building with Test::More < 0.88

* Thu Jul  2 2015 Paul Howarth <paul@city-fan.org> - 0.041-1
- Update to 0.041
  - Accept non-ASCII whitespace under /x: the Whitespace object can be
    multiple characters; the perl_version_introduced() becomes '5.021001' if
    any of them is a code point above 127
  - The perl_version_removed() method now returns '5.021001' when called
    on a PPIx::Regexp object produced by parsing '?foo?' (match once
    without explicit 'm'); the object produced by parsing 'm?foo?' still
    returns the minimum Perl version
  - Report \C (match octet) as removed in 5.23.0
- Update patch for building with Test::More < 0.88

* Sat Jun 27 2015 Paul Howarth <paul@city-fan.org> - 0.040-3
- Perl 5.22 rebuild

* Sun May 31 2015 Paul Howarth <paul@city-fan.org> - 0.040-1
- Update to 0.040
  - Report /n (no captures) as having been added in 5.21.8
  - Do not parse unadorned parentheses as capture groups when /n is in effect;
    instead, they are parsed as PPIx::Regexp::Structure (named captures appear
    to be unaffected by /n)
  - Made a verbose dump a little more so; specifically, dump max_capture_group
    where relevant, and display dumped values a bit more informatively
- Update patch for building with Test::More < 0.88

* Fri Apr  3 2015 Paul Howarth <paul@city-fan.org> - 0.039-1
- Update to 0.039
  - Recognize nested subscripts in interpolation
  - Add \b{g} (= \b{gcb})
- Update patch for building with Test::More < 0.88

* Tue Mar 10 2015 Paul Howarth <paul@city-fan.org> - 0.038-1
- Update to 0.038
  - Handle the boundary assertions introduced in Perl 5.21.9: '\b{gcb}'
    (grapheme cluster boundary), '\b{wb}' (word boundary), '\b{sb}' (sentence
    boundary), and the corresponding '\B{...}' constructions
  - Similar-looking things like '\b{foo}' are not recognized as assertions, and
    are treated as unknown tokens (and therefore an error)
- Update patch for building with Test::More < 0.88

* Thu Nov 13 2014 Paul Howarth <paul@city-fan.org> - 0.037-1
- Update to 0.037
  - Correctly mark the replacement portion of s///ee as code; prior to this
    release it was parsed as though no /e were present
  - Make available the number of times a given modifier is asserted (except
    for the match semantics modifiers, which get handled differently); see
    PPIx::Regexp::Token::Modifier->asserted() and
    PPIx::Regexp::Tokenizer->modifier() for details
  - Have PPIx::Regexp::Structure::RegexSet POD recognize that the Perl docs
    (specifically perlrecharclass) now call this construction Extended
    Bracketed Character Classes, not sets
- Update patch for building with Test::More < 0.88

* Wed Sep 10 2014 Paul Howarth <paul@city-fan.org> - 0.036-3
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible
- BR: perl(Test::CPAN::Changes) unconditionally

* Mon Jan  6 2014 Paul Howarth <paul@city-fan.org> - 0.036-1
- Update to 0.036
  - Retract the "Allow non-ASCII white space under /x" change introduced in
    version 0.033; I misread perl5170delta, and implemented early
  - Change to explicit character class to recognize white space under /x; I
    was previously using \s, which matched too much
- Update patch for building with Test::More < 0.88

* Sat Nov 16 2013 Paul Howarth <paul@city-fan.org> - 0.035-1
- Update to 0.035
  - Properly handle multi-character modifiers like /ee; we now handle /eie as
    being the same as /eei
  - Properly handle \g and \k back references that do not correspond to an
    actual capture group; they are now reblessed into the unknown token, and
    counted as errors
  - Add method error() to PPIx::Regexp::Element; this should return an error
    message when the element is in error - normally when it has been blessed
    into the unknown token or structure
  - Add method modifier_asserted() to PPIx::Regexp::Element; this walks the
    parse tree backward to determine if the given modifier is in effect for the
    element
- Update patch for building with Test::More < 0.88

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 0.034-3
- Perl 5.18 rebuild

* Fri Jul  5 2013 Paul Howarth <paul@city-fan.org> - 0.034-2
- Don't BR: perl(Test::Kwalitee) when bootstrapping

* Mon May 13 2013 Paul Howarth <paul@city-fan.org> - 0.034-1
- Update to 0.034
  - Correct spelling and grammar errors in POD and comments (CPAN RT#85050)

* Sun Feb 24 2013 Paul Howarth <paul@city-fan.org> - 0.033-1
- Update to 0.033
  - Allow interpolation in regex sets; it implies Perl 5.17.9 or higher
  - Allow non-ASCII white space under /x; it implies Perl 5.17.9 or higher

* Thu Feb  7 2013 Paul Howarth <paul@city-fan.org> - 0.032-1
- Update to 0.032
  - Fix problems with Regex Set functionality under Perl 5.6.2
- Update patch for building with Test::More < 0.88

* Fri Feb  1 2013 Paul Howarth <paul@city-fan.org> - 0.031-1
- Update to 0.031
  - Have PPIx::Regexp::Token::Code (and offspring) become
    PPIx::Regexp::Token::Unknown inside a regex set
- Update patch for building with Test::More < 0.88

* Wed Jan 23 2013 Paul Howarth <paul@city-fan.org> - 0.030-1
- Update to 0.030
  - Add Regex Sets, which were added to Perl as an experimental feature in
    5.17.8; this is experimental in Perl and therefore the parse may change
  - Ditch PPIx::Regexp::Token::GroupType method __expect_after_match() in
    favour of the more general __match_setup(); this is done without
    deprecation because __expect_after_match() was documented as
    package-private, but noted in the change log because it _was_ documented
- Update patch for building with Test::More < 0.88

* Mon Jan 14 2013 Paul Howarth <paul@city-fan.org> - 0.029-1
- Update to 0.029
  - Fix mis-parse of /(\?|I)/ as a branch reset (it's really an alternation)
  - Add options -files and -objectify to eg/predump
  - Add method unescaped_content() to PPIx::Regexp::Element()
  - Rewrite the tokenizing code in PPIx::Regexp::Token::GroupType and offspring
    to use regular expressions specific to the regexp delimiter, and escaping
    only that delimiter
- Update patch for building with Test::More < 0.88
- BR: perl(Test::Perl::Critic) on all Perl versions

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.028-3
- Perl 5.16 post-bootstrap rebuild

* Thu Jul 12 2012 Paul Howarth <paul@city-fan.org> - 0.028-2
- Perl 5.16 rebuild

* Thu Jun  7 2012 Paul Howarth <paul@city-fan.org> - 0.028-1
- Update to 0.028
  - Replace all uses of YAML::Any with YAML, since they come in the same
    distro, and YAML does not suffer from deprecation warnings
- BR: perl(base)
- Update patch for building with Test::More < 0.88

* Mon May 28 2012 Paul Howarth <paul@city-fan.org> - 0.027-1
- Update to 0.027
  - Eliminate unescaped literal "{" characters in regexps in
    PPIx::Regexp::Token::Backreference and
    PPIx::Regexp::Token::CharClass::Simple; these are deprecated in 5.17.0
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
- Update patch for building with Test::More < 0.88

* Sat Feb 25 2012 Paul Howarth <paul@city-fan.org> - 0.026-1
- Update to 0.026
  - Add support for \F (fold case), added in 5.15.8
- Update patch for building with Test::More < 0.88

* Wed Feb  8 2012 Paul Howarth <paul@city-fan.org> - 0.025-2
- Don't BR: perl(Test::Perl::Critic) if we're bootstrapping

* Thu Jan  5 2012 Paul Howarth <paul@city-fan.org> - 0.025-1
- Update to 0.025
  - Tolerate leading and trailing white space around the regular expression;
    these are still round-trip safe, since the white space is tokenized
  - Make Changes file conform to CPAN::Changes, and add xt/author/changes.t
    to ensure continued compliance
- BR: perl(Test::CPAN::Changes)
- Update patch for building with Test::More < 0.88

* Mon Dec 19 2011 Paul Howarth <paul@city-fan.org> - 0.024-1
- Update to 0.024
  - Reinstate author test xt/author/manifest.t, which was clobbered shortly
    before the release of 0.021_10
- Explicitly disable debuginfo package to avoid interfering with manifest test
- Update patch for building with Test::More < 0.88

* Thu Dec  8 2011 Paul Howarth <paul@city-fan.org> - 0.023-1
- Update to 0.023
  - Correct address of FSF in the version of the GPL distributed in
    LICENSES/Copying
- Update patch for building with old Test::More versions

* Fri Nov 25 2011 Paul Howarth <paul@city-fan.org> - 0.022-1
- Update to 0.022
  - Support for default modifiers, including:
    - default_modifiers argument to new() in PPIx::Regexp,
      PPIx::Regexp::Tokenizer, and PPIx::Regexp::Dumper
    - Public method modifier_asserted() on PPIx::Regexp, to return
      whether a given modifier is actually in effect
  - Don't initialize effective modifiers with '^', since that wrongly
    asserts that /d has been seen somewhere along the line
  - Implement negation of match-semantic modifiers (e.g. 'no re /u;') by
    setting the relevant datum to undef
  - Fix PPIx::Regexp::Token::Whitespace->can_be_quantified() to return
    false
  - Require Test::More 0.88 for installation
  - Have Makefile.PL make use of {BUILD_REQUIRES} if it is available
  - Correct various documentation errors
- Patch test suite to work with Test::More < 0.88 if necessary
- Run author tests (except the spelling check, which has surprising failures)
- Add buildreqs for author tests:
  - perl(ExtUtils::Manifest)
  - perl(Test::Kwalitee)
  - perl(Test::Perl::Critic)
  - perl(Test::Pod) ≥ 1.0
  - perl(Test::Pod::Coverage) ≥ 1.0

* Sat Jul 23 2011 Paul Howarth <paul@city-fan.org> - 0.021-2
- Rebuild for perl 5.14.1 in Rawhide

* Sat Jul 23 2011 Paul Howarth <paul@city-fan.org> - 0.021-1
- Update to 0.021
  - Modified tokenizer to correctly handle a back slash used as a delimiter
  - PPIx::Regexp::Dumper now dumps the results of ppi() if that method is
    present and -verbose is asserted
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Apr  4 2011 Paul Howarth <paul@city-fan.org> - 0.020-1
- Update to 0.020
  - Corrected perl_version_introduced(): \R is now 5.009005 (was 5.000)
- Move module back to vendor directories rather than perl directories
- Nobody else likes macros for commands

* Wed Mar  2 2011 Paul Howarth <paul@city-fan.org> - 0.019-1
- Update to 0.019
  - Various corrections to perl_version_introduced():
    - \X is now 5.006 (was 5.000)
    - \N{name} is now 5.006001 (was 5.006)
    - \N{U+xxxx} is now 5.008 (was 5.006)
  - The \C is now parsed as a PPIx::Regexp::Token::CharClass::Simple
  - Ensure that \N{$foo} parses as a Unicode literal, not a quantified \N;
    the ordinal() method returns undef for this.
  - Understand the /aa modifier, introduced with 5.13.10
  - Report perl_version_introduced() of 5.013010 for the new semantic
    modifiers when modifying the entire expression
  - Correct handling of interpolations like ${^foo} and $#{foo}

* Thu Feb 17 2011 Paul Howarth <paul@city-fan.org> - 0.018-1
- Update to 0.018
  - Take account of possible '$' or '@' casts before a symbol in an
    interpolation (e.g. $$foo{bar}, which is equivalent to $foo->{bar})
  - Override ppi() in PPIx::Regexp::Token::Interpolation to provide the
    proper PPI when variable names are bracketed
  - Properly parse bracketed variable names, which may not be subscripted

* Thu Jan 27 2011 Paul Howarth <paul@city-fan.org> - 0.017-1
- Update to 0.017
  - Add the /a modifier to PPI::Regexp::Token::Modifiers, legal only in the
    (?:...) construction
  - When parsing an interpolation from a replacement string (rather than a
    regular expression), take subscripts at face value rather than trying to
    disambiguate them from quantifiers and character classes, which they can't
    be in this context
- Install to perl dirs rather than vendor dirs

* Thu Jan  6 2011 Paul Howarth <paul@city-fan.org> - 0.016-1
- Update to 0.016
  - The PPIx::Regexp::Token::Code perl_version_introduced() method now returns
    the minimum Perl version (currently set to 5.000) if it is used to
    represent the substitution portion of s///e

* Wed Dec 15 2010 Paul Howarth <paul@city-fan.org> - 0.015-2
- Import from Fedora

* Wed Oct 27 2010 Petr Pisar <ppisar@redhat.com> - 0.015-1
- 0.015 bump

* Mon Oct 18 2010 Petr Pisar <ppisar@redhat.com> - 0.014-1
- 0.014 bump

* Mon Oct 04 2010 Petr Pisar <ppisar@redhat.com> - 0.012-1
- 0.012 bump

* Wed Sep 22 2010 Petr Pisar <ppisar@redhat.com> - 0.011-1
- 0.011 bump
- Remove unversioned Requires

* Thu Sep 16 2010 Petr Pisar <ppisar@redhat.com> - 0.010-1
- 0.010 bump

* Tue Jun  8 2010 Petr Pisar <ppisar@redhat.com> - 0.007-1
- Specfile autogenerated by cpanspec 1.78 (bug #598553)
